@@ -11,7 +11,6 @@
 -- because "Text.Microstache" re-exports everything you may need, import that
 -- module instead.
 
-{-# LANGUAGE CPP                        #-}
 {-# LANGUAGE DeriveDataTypeable         #-}
 {-# LANGUAGE DeriveGeneric              #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
@@ -30,17 +29,18 @@ module Text.Microstache.Type
   )
 where
 
-import Control.DeepSeq
+import Control.DeepSeq   (NFData (..))
 import Control.Exception (Exception (..))
 import Data.Data         (Data)
 import Data.Map          (Map)
-import Data.Semigroup
+import Data.Monoid       (Monoid (..))
+import Data.Semigroup    (Semigroup (..))
 import Data.String       (IsString (..))
 import Data.Text         (Text)
 import Data.Typeable     (Typeable)
 import Data.Word         (Word)
 import GHC.Generics
-import Text.Parsec
+import Text.Parsec       (ParseError)
 
 import qualified Data.Map  as Map
 import qualified Data.Text as T
@@ -130,9 +130,7 @@ displayMustacheException (MustacheRenderException pname key) =
     "\", key: " ++ T.unpack (showKey key)
 
 instance Exception MustacheException where
-#if MIN_VERSION_base(4,8,0)
     displayException = displayMustacheException
-#endif
 
 -- | @since 1.0.1
 data MustacheWarning
@@ -150,6 +148,4 @@ displayMustacheWarning (MustacheDirectlyRenderedValue key) =
     "Complex value rendered as such, key: " ++ T.unpack (showKey key)
 
 instance Exception MustacheWarning where
-#if MIN_VERSION_base(4,8,0)
     displayException = displayMustacheWarning
-#endif
